/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

function GmapViewer() 
{
  
  return {
      
    addMarkers: function()
    {
    	var me = this;
    	$j.each(this.data.markers, function (idx, elem) {
    		me.addMarker(elem);
    	});
    },
  
    addMarker: function (record)
    {
    	$j(this.mapId).gMap("addMarker", {
    		latitude: record.lat, 
    		longitude: record.lng,
    		options: {
    			animation: google.maps.Animation.DROP
    		},
    		icon: {
    			image: this.pinImageUrl(record.icon, record.number, record.letter),
    			iconsize: record.iconSize || [32,37]
    		},
    		html: this.renderHtmlTooltip(record.title, record.description)
        });
    },
  
    addPolygons: function() 
    {
    	var me = this;
    	$j.each(this.data.polygons, function (idx, elem) {
    		me.addPolygon(elem);
    	});
    },
  
    addPolygon: function (record)
    {
    	$j(this.mapId).gMap("addPolygon", {
    		points: record.points,
    		options: {
    			fillColor: '#' + record.color,
    			strokeColor: '#' + record.color,
    			html: this.renderHtmlTooltip(record.title, record.description)
    		},
    		html: this.renderHtmlTooltip(record.title, record.description)
        });
    },
    
    renderHtmlTooltip: function(title, desc)
    {
    	return '<div class="infowindow"><span class="title">'+ title +'</span>'
		+ '<p class="description">'+ (desc || '') +'</p>'
		+ '</div>';
    },
      
    pinImageUrl: function (icon, number, letter) 
    {
    	var url = '';   
    	if (letter)
    	{
    		url = this.data.iconBase + 'letter/' + letter + '.png';
    	}
    	else if (number)
    	{
    		url = this.data.iconBase + 'number/' + number + '.png';
    	}
    	else
    	{
    		 url = this.data.iconBase + icon + '.png';
    	}
    	return url;
    },
    
    setUp: function (mapIdentifier, gdata, fitbounds)
    {
    	this.mapId = mapIdentifier;
    	this.data = gdata;
    	this.enableFitbounds = !!fitbounds;
      
    	if (this.data && this.mapId)
    	{
    		if (this.gmap)
			{
    			$j(this.mapId).gMap("removeAllMarkers");
    			$j(this.mapId).gMap("removeAllPolygons");
			}
    		
    		this.prepareFitbounds();
    		this.gmap = this.initMap(this.data.lat, this.data.lng, this.data.zoomLevel, this.data.mapTypeId);
    		
    		this.fitbounds();
    		this.addMarkers();
    		this.addPolygons();
    	}
    },
  
    initMap: function (lat, lng, zoomLevel, mapTypeId)
    {
    	if (!this.mapId) return;
    	
    	var latitude = lat;
    	var longitude = lng;
    	var c;
    	
    	if (this.enableFitbounds && this.boundCount > 0)
		{
    		c = this.bounds.getCenter();
    		latitude = c.lat();
    		longitude = c.lng();
		}
		
//    	if (!this.gmap)
//    	{
//    		console.log('???');
    		
			return $j(this.mapId).gMap({
				latitude: latitude,
				longitude: longitude,
				zoom:zoomLevel,
				maptype:mapTypeId,
				mapTypeControl:true,
			  	zoomControl:true,
			  	panControl:true,
			  	streetViewControl:false
			});
//    	}
//    	else
//		{
//    		// do re-init...
//    		// set center + zoomlevel
//    		console.log('reinit map!!');
//    		return this.gmap;
//		}
    },
    
    prepareFitbounds: function()
    {
    	if (!this.enableFitbounds)
		{
    		return;
		}
    	
		this.bounds = new google.maps.LatLngBounds();
		this.boundCount = 0;
    	
		var me = this;
		
    	// markers
    	$j.each(this.data.markers, function (idx, elem) {
    		me.bounds.extend(new google.maps.LatLng(elem.lat, elem.lng));
    		me.boundCount++;
    	});
    	
    	// polygons
    	var p, pl, pi;
    	$j.each(this.data.polygons, function (idx, elem) {
    		p = elem.points;
    		pl = p ? p.length : 0;
    		
	    	if (p)
			{
	    		for (var i = 0; i < pl; i++)
				{
	    			pi = p[i];
	    			this.bounds.extend(new google.maps.LatLng(pi.lat, pi.lng));
	    			this.boundCount++;
				}
			}
    	});
    },
    
    fitbounds: function()
    {
		if (this.enableFitbounds && this.boundCount >= 2)
		{
			this.gmap.data('$gmap').fitBounds(this.bounds);
		}
    }
  }
};