/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * @class This class provides an {@link org.ametys.ribbon.control.button.ActionButton} which is enabled if the selection is an editable resource or collection
 * @extends {@link org.ametys.ribbon.control.button.PageAttachmentButton}
 */
Ext.namespace('org.ametys.ribbon.control.button');

/**
 * Create the control instance.
 * @class This class provides an {@link org.ametys.ribbon.control.button.ActionButton} which is enabled if the selection is a resource explorer node.<br/>The button needs the 'application-id' configuration.
 * @extends {@link org.ametys.ribbon.control.button.ActionButton}
 * @param {String} id The unique identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} pluginName The name of the declaring plugin
 * @constructor
 */
org.ametys.ribbon.control.button.PageAttachmentNotRootButton = function(id, configuration, pluginName)
{
	org.ametys.ribbon.control.button.PageAttachmentNotRootButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.ribbon.control.button.PageAttachmentNotRootButton, org.ametys.ribbon.control.button.PageAttachmentButton, {});

org.ametys.ribbon.control.button.PageAttachmentNotRootButton.prototype._isDisabled = function (target)
{
	if (this._isRoot(target))
	{
		return true;
	}
	
	org.ametys.ribbon.control.button.PageAttachmentNotRootButton.superclass._isDisabled.call(this, target);
}

org.ametys.ribbon.control.button.PageAttachmentNotRootButton.prototype._isRoot = function (target)
{
	var resourceTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(target.getSubTargets(), function(target) { return target.getType() == "resources-explorer-node" });
	return resourceTarget.getParameters().rootIds.indexOf(resourceTarget.getParameters().id) >= 0;
}
