/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

org.ametys.ribbon.control.button.PreviewPageButton = function(id, configuration, pluginName) 
{
	org.ametys.ribbon.control.button.PreviewPageButton.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.ribbon.control.button.PreviewPageButton, org.ametys.ribbon.control.button.ActionButton, {});

/**
 * @private
 * @property {Map<String, String>} _lastParams The parameters received on the last refresh
 */
org.ametys.ribbon.control.button.PreviewPageButton.prototype._lastParams;

/**
 * @private
 * @property {String[]} _currentPagesId The pages id currently selected or null. 
 */
org.ametys.ribbon.control.button.PreviewPageButton.prototype._currentPagesId;

org.ametys.ribbon.control.button.PreviewPageButton.prototype._areTheSame = function (tab1, tab2)
{
	if (tab1 == tab2)
	{
		return true;
	}

	if (tab1 == null || tab2 == null || tab1.length != tab2.length)
	{
		return false;
	}	
	
	for (var i=0; i < tab1.length; i++)
	{
		if (tab2.indexOf(tab1[i]) == -1)
		{
			return false;
		}
	}
	
	return true;
}

org.ametys.ribbon.control.button.PreviewPageButton.prototype._doReload = function()
{
	if (this._currentPagesId.length == 1)
	{
		this.getElements().each(
			function(element)
			{
				element.setDisabled(true);
				element.refreshing();
			}
		);
		this.updateTooltip(this.getConfiguration()["refresh-description"]);
		org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {targets: this._currentPagesId});
	}
}
org.ametys.ribbon.control.button.PreviewPageButton.prototype.onMessage = function (messages)
{
	// SELECTION
	for (var i=messages.length - 1; i >= 0; i--)
	{
		var changedButNotASelection = (messages[i].getType().getName() == "typeChanged" || messages[i].getType().getName() == "templateChanged");
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED || changedButNotASelection)
		{
			var targets = messages[i].getTargets();
			var allTargets = this._convertToId(org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, this.checkTarget()));
			
			// No page selected
			if (allTargets.length == 0)
			{
				this._currentPagesId = [];
				this.getElements().each(function(element) { element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["default-description"]);
				break;
			}
			// A single target selected or multiselection is enabled
			else if (allTargets.length == 1)
			{
				if (!this._areTheSame(this._currentPagesId, allTargets) || changedButNotASelection)
				{
					this._currentPagesId = allTargets;
					this.getElements().each(function(element) { element.setDisabled(true); element.refreshing(); });
					this.updateTooltip(this.getConfiguration()["refresh-description"]);
					org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {targets: this._currentPagesId});
					break;
				}
			}
			// Too many pages selected
			else
			{
				this._currentPagesId = [];
				this.getElements().each(function(element) { element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["multiselection-disabled-description"]);
				break;
			}
		}
	}
}

org.ametys.ribbon.control.button.PreviewPageButton.prototype._convertToId = function (targets)
{
	var targetsIds = [];
	for (var i = 0; i < targets.length; i++)
	{
		targetsIds.push(targets[i].getParameters()['id']);
	}
	return targetsIds;
}
org.ametys.ribbon.control.button.PreviewPageButton.prototype.checkTarget = function ()
{
	return function (target) { return target.getType() == 'page'; };
}

org.ametys.ribbon.control.button.PreviewPageButton.prototype.configurationError = function(response)
{
	this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
	this.updateTooltip(this.getConfiguration()["default-description"]);
}

org.ametys.ribbon.control.button.PreviewPageButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });

	var count = parseInt(params["allright-page-size"]);
	if (count > 0)
	{
		this.updateTooltip(this.getConfiguration()["ok-description"]);
	}
	else
	{
		this.updateTooltip(this.getConfiguration()["error-description"]);
	}
	
	this.getElements().each(function(element) { element.setDisabled(count == 0); });
	this._lastParams = params;
}
