/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.control.button');

org.ametys.ribbon.control.button.ScheduleActionButton = function(id, configuration, pluginName) 
{
	org.ametys.ribbon.control.button.ScheduleActionButton.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.ribbon.control.button.ScheduleActionButton, org.ametys.ribbon.control.button.ActionButton, {});

/**
 * @private
 * @property {Map<String, String>} _lastParams The parameters received on the last refresh
 */
org.ametys.ribbon.control.button.ScheduleActionButton.prototype._lastParams;

/**
 * @private
 * @property {String[]} _currentPagesId The pages id currently selected or null. 
 */
org.ametys.ribbon.control.button.ScheduleActionButton.prototype._currentPagesId;

org.ametys.ribbon.control.button.ScheduleActionButton.prototype._areTheSame = function (tab1, tab2)
{
	if (tab1 == tab2)
	{
		return true;
	}

	if (tab1 == null || tab2 == null || tab1.length != tab2.length)
	{
		return false;
	}	
	
	for (var i=0; i < tab1.length; i++)
	{
		if (tab2.indexOf(tab1[i]) == -1)
		{
			return false;
		}
	}
	
	return true;
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype._doReload = function()
{
	if (this._currentPagesId.length == 0)
	{
		this.getElements().each(function(element) { element.setDisabled(true); });
		this.updateTooltip(this.getConfiguration()["default-description"]);
	}
	if (this._currentPagesId.length == 1)
	{
		this.getElements().each(function(element) { element.setDisabled(true); element.refreshing(); });
		this.updateTooltip(this.getConfiguration()["refresh-description"]);
		org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {targets: this._currentPagesId});
	}
	else
	{
		this.getElements().each(function(element) { element.setDisabled(true); });
		this.updateTooltip(this.getConfiguration()["multiselection-disabled-description"]);
	}
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype.onMessage = function (messages)
{
	// SELECTION
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var allTargets = org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, this.checkTarget());
			var allTargetsId = this._convertToId(allTargets);
			
			// No page selected
			if (allTargets.length == 0)
			{
				this._currentPagesId = [];
				this._doReload();
			}
			// A single target selected 
			else if (allTargets.length == 1)
			{
				if (!this._areTheSame(this._currentPagesId, allTargetsId))
				{
					this._currentPagesId = allTargetsId;
					
					if (allTargets[0].getParameters().isModifiable != 'true')
					{
						var iconSmall = context.contextPath + this.getConfiguration()['icon-small'];
						var iconLarge = context.contextPath + this.getConfiguration()['icon-medium'];
						
						this.getElements().each(
								function (element) 
								{
									element.iconSmall = iconSmall;
									element.iconLarge = iconLarge;
								}
							);
						
						this.getElements().each(function(element) { element.updateIcon(); });
						this.updateTooltip(this.getConfiguration()["no-modifiable-description"], iconLarge, null);
						
						this.getElements().each(function(element) {element.disable();});
					}
					else
					{
						this._doReload();
					}
				}
			}
			// Too many pages selected
			else
			{
				this._currentPagesId = [];
				this._doReload();
			}
			
			break;
		}
	}
	
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED
	        || messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_MINORMETADATACHANGED)
		{
			this._doReload();
			break;
		}
	}
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype._convertToId = function (targets)
{
	var targetsIds = [];
	for (var i = 0; i < targets.length; i++)
	{
		targetsIds.push(targets[i].getParameters()['id']);
	}
	return targetsIds;
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype.checkTarget = function ()
{
	return function (target) { return target.getType() == 'page'; };
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype._handlingMultiple = function(tooltip, paramPrefix, params)
{
	var count = parseInt(params[paramPrefix + "-size"]);
	if (count > 0)
	{
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		
		for (var i=0; i < count; i++)
		{
			if (i != 0) 
			{
				tooltip += "<br/>";
			}
			
			tooltip += this.getConfiguration()[paramPrefix + "-start-description"];
			tooltip += params[paramPrefix + "-" + i];
			tooltip += this.getConfiguration()[paramPrefix + "-end-description"];
			
			if (params["scheduled-page-startdate-" + i] != null)
			{
				tooltip += "<br/>";
				tooltip += this.getConfiguration()["scheduled-page-startdate-start-description"];
				tooltip += params["scheduled-page-startdate-" + i];
				tooltip += this.getConfiguration()["scheduled-page-startdate-end-description"];
			}
			
			if (params["scheduled-page-enddate-" + i] != null)
			{
				tooltip += "<br/>";
				tooltip += this.getConfiguration()["scheduled-page-enddate-start-description"];
				tooltip += params["scheduled-page-enddate-" + i];
				tooltip += this.getConfiguration()["scheduled-page-enddate-end-description"];
			}
			
		}
	}
	
	return tooltip;
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype._getIcon = function(params)
{
	var nbScheduledPages = parseInt(params['scheduled-page-size']);
	var nbValidPages = parseInt(params['scheduled-page-valid-size']);
	var nbOutOfDatePages = parseInt(params['scheduled-page-outofdate-size']);
	var nbForthComingPages = parseInt(params['scheduled-page-forthcoming-size']);
	
	if (nbScheduledPages > 0 && nbValidPages > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['on-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['on-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	if (nbScheduledPages > 0 && nbForthComingPages > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['forthcoming-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['forthcoming-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	if (nbScheduledPages > 0 && nbOutOfDatePages > 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['outofdate-icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['outofdate-icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
	
	if (nbScheduledPages == 0)
	{
		var iconSmall = context.contextPath + this.getConfiguration()['icon-small'];
		var iconLarge = context.contextPath + this.getConfiguration()['icon-medium'];
		this.getElements().each(
			function (element) 
			{
				element.iconSmall = iconSmall;
				element.iconLarge = iconLarge;
			}
		);
	}
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype.configurationError = function(response)
{
	this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
	this.updateTooltip(this.getConfiguration()["default-description"]);
}

org.ametys.ribbon.control.button.ScheduleActionButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });
	
	var tooltip = this._handlingMultiple(this.getConfiguration()["default-description"], "scheduled-page-valid", params);
	tooltip = this._handlingMultiple(tooltip, "scheduled-page-outofdate", params);
	tooltip = this._handlingMultiple(tooltip, "scheduled-page-forthcoming", params);
	
	var isDisabled = params['scheduled-page-norights-size'] != '0'; 
	if (isDisabled)
	{
		tooltip += "<br/><br/>";
		tooltip += this.getConfiguration()["norights-description"];
	}
	
	// Icon
	this._getIcon(params);
	
	this.getElements().each(function(element) { element.updateIcon(); });
	this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
	
	var nbScheduledPages = parseInt(params['scheduled-page-size']);
	this.getElements().each(function(element) { element.toggle(nbScheduledPages > 0); });	
	this.getElements().each(function(element) { element.setDisabled(isDisabled); });
	
	this._lastParams = params;
}
