/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.ribbon.tab');

/**
 * Do not call this contructor
 * @constructor
 * @class This class handles the tab that shows when selection is of the configured type
 * @param {String} id The unique tab identifier
 * @param {Map<id, value>} configuration The configuration of the control instance. The key 'target-type' represents the name of the target that will make the tab show when this kind of target is in the {@see org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED} message.
 * @param {String} The name of the plugin where the control was declared
 * @param {Ext.Panel} The panel of the tab
 */
org.ametys.ribbon.tab.ServiceTab = function(id, configuration, pluginName, tabPanel) 
{
	org.ametys.ribbon.tab.ServiceTab.superclass.constructor.call(this, id, configuration, pluginName, tabPanel);
}

Ext.extend(org.ametys.ribbon.tab.ServiceTab, org.ametys.ribbon.control.RibbonTab, {});


/**
 * Activate or deactivate the tab depending on the selection
 * @param {org.ametys.messagebus.message.Message[]} messages The messages received.
 * @private
 */
org.ametys.ribbon.tab.ServiceTab.prototype.onMessage = function (messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function(target) {return target.getType() == 'zoneitem'});

			if (target != null && target.getParameters().type == 'service')
			{
				this.show();
			}
			else
			{
				this.hide();
			}
		}
	}
	
}
