/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.web.tool.explorer');

/**
 * Do not call this constructor. Declared to and used by the {@see org.ametys.uitool.ToolsManager}
 * @constructor
 * @extends org.ametys.uitool.tool.impl.UniqueInstanceToolFactory
 * @class The factory to creates the resources explorer tool.
 * @param {String} id The unique id of the factory
 * @param {Map} config Options 
 * @param {String} pluginName The name of the plugin where the factory was declared
 */
org.ametys.web.tool.explorer.SimpleResourcesExplorerToolFactory = function(id, config, pluginName) 
{
	org.ametys.web.tool.explorer.SimpleResourcesExplorerToolFactory.superclass.constructor.call(this, id, config, pluginName);
};
Ext.extend(org.ametys.web.tool.explorer.SimpleResourcesExplorerToolFactory, org.ametys.uitool.tool.impl.UniqueInstanceToolFactory, {});

org.ametys.web.tool.explorer.SimpleResourcesExplorerToolFactory.prototype.createTool = function (id)
{
	return new org.ametys.web.tool.explorer.SimpleResourcesExplorerTool(id, this.getPluginName());
}

org.ametys.web.tool.explorer.SimpleResourcesExplorerToolFactory.prototype.openTool = function(params) 
{
	// We can use the factory id, because this factory will handle only one tool.
	if (org.ametys.uitool.ToolsManager.getInstance().getTool(this._id) == null)
	{
		if (this._tool == null)
		{
			// Tool does not exists => Tool creation.
			// We can use the factory id, because this factory will handle only one tool.
			this._tool = this.createTool(this._id);
			this._tool.setFactory (this); 
			this._tool.setConfiguration(this._config);
		}
		
		org.ametys.uitool.ToolsManager.getInstance().addUITool (this._tool, this._config['default-location']);
	}	

	this._tool.setParams(params);
	org.ametys.uitool.ToolsManager.getInstance().activateTool (this._tool, this._config['default-location']);
	
	return this._tool;
}
