/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.web.tool.pageaccess.control');

org.ametys.web.tool.pageaccess.control.SetAnyUserButton = function(id, configuration, pluginName)
{
	org.ametys.web.tool.pageaccess.control.SetAnyUserButton.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.web.tool.pageaccess.control.SetAnyUserButton, org.ametys.ribbon.control.button.RightActionSelectionButton, {});

/**
 * Creates the toggle button
 * @param {String} size The size between 'large', 'small' and 'very-small'
 * @param {integer} colspan The configured colspan. Must be transmited to the control.
 * @return {Ext.form.field} The toggle button created. 
 */
org.ametys.web.tool.pageaccess.control.SetAnyUserButton.prototype.createControl = function(size, colspan)
{
    org.ametys.messagebus.MessageBus.getInstance().register(this);
    
    var initFn = this.getConfiguration()['initialize'];
    if (initFn != null)
    {
        eval(initFn + "(this.getId(), this.getConfiguration(), this.getPluginName());");
    }
    
    this._toolTipImage = this._getTooltipImage ();
    this._toolTipText = this.getConfiguration()['default-description'];
    this._toolTipFooter = this.getConfiguration()['footer'];
    
    var element = new org.ametys.fluent.controls.Button({
        text: this.getConfiguration()['label'], 
        iconSmall: context.contextPath + this.getConfiguration()['icon-small'],
        iconLarge: context.contextPath + this.getConfiguration()['icon-medium'],

        size: size,
        colspan: colspan,
        
        tooltip: org.ametys.fluent.Tooltip.create(
            this.getConfiguration()['label'], 
            this._toolTipImage, 
            this._toolTipText, 
            this._toolTipFooter 
        ),
        
        pressed: this.getConfiguration()['pressed'] | false,
        enableToggle: true,
        toggleHandler: this.onToggle,
        
        controlId: this.getId()
    });
    
    this.getElements().add(element);
    
    return element;
}

org.ametys.web.tool.pageaccess.control.SetAnyUserButton.prototype.onMessage = function(messages)
{
    for (var i=0; i < messages.length; i++)
    {
        if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
        {
            var targets = messages[i].getTargets();
            var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._testTarget.createDelegate(this));
            
            if (target != null)
            {
                if (!this._hasRight(target))
                {
                    var text = this._getTooltip(this.getConfiguration()["no-right-description"]);
                    this.updateTooltip(text, null, null);
                    
                    this.getElements().each(function(element) {element.disable();});
                }
                else
                {
                    var params = {targets: [target.getParameters().id]};
                    
                    // Set the toggled state.
                    org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, params);
                }
            }
            else
            {
                var text = this._getTooltip(this.getConfiguration()["no-selection-description"]);
                this.updateTooltip(text, null, null);
                this.getElements().each(function(element) {element.disable();});
            }
        }
    }
}

org.ametys.web.tool.pageaccess.control.SetAnyUserButton.prototype.configurationError = function(response)
{
    this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
    this.updateTooltip(this.getConfiguration()['default-description']);
}

org.ametys.web.tool.pageaccess.control.SetAnyUserButton.prototype.configurationChanged = function(params)
{
    this.getElements().each(function(element) { element.stopRefreshing(); });
    
    var allowAnyConnectedUserCount = parseInt(params['allow-any-connected-user-count']);
    var inheritedCount = parseInt(params['inherited-rectriction-count']);
    var negativeRestrictionPage = parseInt(params['has-negative-restriction-count']);
    
    var toggledState = allowAnyConnectedUserCount > 0 && inheritedCount == 0;
    var disabledState = allowAnyConnectedUserCount > 0 && inheritedCount > 0 && negativeRestrictionPage == 0;
    
    this.updateTooltip(this.getConfiguration()["default-description"], null, null);
    
    this.getElements().each(function(element) {
        element.setDisabled(disabledState);
        element.toggle(toggledState, true);
    });
}

/**
 * @private
 * This handler is called when the toogle button state change
 */
org.ametys.web.tool.pageaccess.control.SetAnyUserButton.prototype.onToggle = function(button, state)
{
    var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[this.controlId];
    if (control.getConfiguration()['action'] != null)
    {
        eval(control.getConfiguration()['action'] + "(control.getId(), control.getConfiguration(), control.getPluginName(), state);");
    }
}
