/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

// Ametys Namespace
Ext.namespace('org.ametys.web.tree');

org.ametys.web.tree.TagXmlLoader = Ext.extend(org.ametys.tree.XmlTreeLoader, {});

org.ametys.web.tree.TagXmlLoader.prototype.processResponse = function(response, node, callback) 
{
	this._nodeTags = {};
	this._nodeTags['tagprovider'] = '';
	this._nodeTags['category'] = '';
	this._nodeTags['tag'] = '';
	
	org.ametys.web.tree.TagXmlLoader.superclass.processResponse.call(this, response, node, callback);
}

org.ametys.web.tree.TagXmlLoader.prototype.processAttributes = function(attr)
{
	org.ametys.web.tree.TagXmlLoader.superclass.processAttributes.call(this, attr);
	
	if (attr.tagName == "tagprovider")
    { 
		// This is a category node
        attr.text = attr.title;
        attr.type = "category";
        attr.leafSort = false; // attribute for sorting
        
        // Category icon
        attr.icon = getPluginResourcesUrl('web') + '/img/tag/category_16.png';

        if (!attr.hasChild)
        {
       	 	attr.leaf = true;
        }
        if (this.checkMode && this.allowProviders)
        {
       	 	attr.checked = false;
        }
        
        if (this.syncMode)
        {
            // Override these values for our folder nodes because we are loading all data at once.  If we were
            // loading each node asynchronously (the default) we would not want to do this:
            attr.expanded = true;
        	attr.loaded = true;
        }
    }
    else  
    { 
        // this is it a tag node
        attr.text = attr.title;
        attr.type = "tag";
        attr.leafSort = false; // attribute for sorting
        
        var filterVisibility = null; // visibility to filter: null for all tags, 'PRIVATE' for private tags
        
        if (this.filterTarget != null)
        {
        	var filterTargets = Ext.isArray(this.filterTarget) ? this.filterTarget : [this.filterTarget];
        	
        	for (var i=0; i < filterTargets.length; i++)
        	{
        		var filterTarget = filterTargets[i];
        		
        		var j = filterTarget.indexOf('_PRIVATE');
            	if (j >= 0)
            	{
            		filterTarget = filterTarget.substring(0, j); // PAGE or CONTENT
            		filterVisibility = "PRIVATE";
            	}
            	
            	if (attr.target == filterTarget && (filterVisibility == null || attr.visibility == filterVisibility))
            	{
            		attr.disabled = true;
            	}
            	
            	filterVisibility = null; // Re-init filter visibility
        	}
        }
        
        // Tag icon
        if (attr.authorized == 'false')
        {
        	attr.icon = getPluginResourcesUrl('web') + '/img/tag/tag_unauthorized_16.png';
        	attr.disabled = true;
        }
        else if (attr.visibility == 'PRIVATE')
        {
        	attr.icon = getPluginResourcesUrl('web') + '/img/tag/tag_private_16.png';
        }
        else
        {
        	attr.icon = getPluginResourcesUrl('web') + '/img/tag/tag_16.png';
        }

        // Tell the tree this is a leaf node.  This could also be passed as an attribute in the original XML,
        // but this example demonstrates that you can control this even when you cannot dictate the format of
        // the incoming source XML:
   	 	attr.leaf = !attr.hasChild ? true : false;
   	 	
        if (this.checkMode)
        {
        	// empty check box.
            var dontCheck = (!attr.hasChild && this.onlyTagsWithChildren);
       	 	attr.checked = dontCheck ? null : false;
        }
        
        if (this.syncMode)
        {
            // Override these values for our folder nodes because we are loading all data at once.  If we were
            // loading each node asynchronously (the default) we would not want to do this:
            attr.expanded = true;
        	attr.loaded = true;
        }
    }
}

org.ametys.web.tree.TagXmlLoader.prototype.createNode = function(node) 
{
	var attr = {
		tagName :node.tagName
	};

	Ext.each(node.attributes, function(a) {
		attr[a.nodeName] = a.nodeValue;
	});
	
	this._currentXMLNode = node;
	this.processAttributes(attr);
	delete this._currentXMLNode;
	
	if (this.baseAttrs)
    {
        Ext.applyIf(attr, this.baseAttrs);
    }
    if (this.applyLoader !== false)
    {
        attr.loader = this;
    }
    if (typeof attr.uiProvider == 'string')
    {
       attr.uiProvider = this.uiProviders[attr.uiProvider] || eval(attr.uiProvider);
    }
    
	return new Ext.tree.AsyncTreeNode(attr);
}
